@@ -1,6 +1,7 @@
 #' Install packages for a project
 #'
 #' @param deployment Use deployment mode
+#' @return No return value
 #' @export
 #' @examples \dontrun{
 #'
@@ -8,15 +9,13 @@
 #' }
 install <- function(deployment=FALSE) {
   sandbox({
-    prepCommand()
-
     if (deployment) {
       status <- getStatus()
       missing <- getMissing(status)
       if (length(missing) > 0) {
         stop(paste("Missing packages:", paste(missing, collapse=", ")))
       }
-      suppressWarnings(renv::restore(prompt=FALSE))
+      suppressWarnings(renv::restore(prompt=FALSE, repos=getRepos()))
       showStatus(status)
     } else {
       installHelper(show_status=TRUE)
